==> panel-1.3.8rc2.tar.gz: panel-1.3.8rc2/doc/index.md <==
---
sd_hide_title: true
---

```{image} _static/logo_horizontal_dark_theme.png
:class: only-dark homepage-logo
:width: 250px
```

```{image} _static/logo_horizontal_light_theme.png
:class: only-light homepage-logo
:width: 250px
```

# Overview

<h2 style="margin-top: 0.3em;">The powerful data exploration & web app framework for Python</h2>

::::{grid} 2 4 4 4

:::{grid-item-card} Portfolio Analyzer
:link: https://|gallery-endpoint|.pyviz.demo.anaconda.com/portfolio_analyzer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/portfolio_analyzer.png
---
alt: Portfolio Analyzer App
---
```
:::

:::{grid-item-card} Portfolio Optimizer
:link: https://|gallery-endpoint|.pyviz.demo.anaconda.com/portfolio_optimizer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/portfolio_optimizer.png
---
alt: Portfolio Optimizer App
---
```
:::

:::{grid-item-card} MRI Slicer
:link: https://|gallery-endpoint|.pyviz.demo.anaconda.com/vtk_slicer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/vtk_slicer.png
---
alt: VTK 3D Slicer App
---
```
:::

:::{grid-item-card} Videostream
:link: https://|gallery-endpoint|.pyviz.demo.anaconda.com/streaming_videostream
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/streaming_videostream.png
---
alt: scikit-image Videostream App
---
```
:::

::::

Panel is an [open-source](https://github.com/holoviz/panel/blob/main/LICENSE.txt) Python library that lets you **easily build powerful tools, dashboards and complex applications entirely in Python**. It has a batteries-included philosophy, putting the PyData ecosystem, powerful data tables and much more at your fingertips. High-level reactive APIs and lower-level callback based APIs ensure you can quickly build exploratory applications, but you aren't limited if you build complex, multi-page apps with rich interactivity. Panel is a member of the [HoloViz](https://holoviz.org/) ecosystem, your gateway into a connected ecosystem of data exploration tools.

```{notebook} panel ../examples/homepage.ipynb
:disable_interactivity_warning: True
````

Panel makes it simple to:

- Develop in your favorite **editor or notebook** environment
- Combine the **PyData tools and plotting libraries** that you know and love
- **Iterate quickly** to develop data tools, dashboards and complex apps
- **Collaborate** across skill levels and tool preferences
- Add **advanced bi-directional communication** to your data apps
- Create interactive **big data** applications with **crossfiltering**
- Create **high performing**, **streaming** data applications
- Create data apps that **can run entirely in the browser**
- Create **polished, performant, secure and production-ready web applications**

---

Enjoying Panel? Show your support with a [Github star](https://github.com/holoviz/panel) — it’s a simple click that means the world to us and helps others discover it too! ⭐️

## Usage

::::{grid} 1 2 2 4
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1` Getting Started
:link: getting_started/index
:link-type: doc

The getting started guide will get you set up with Panel and provide a basic overview of the features and strengths of Panel.
:::

:::{grid-item-card} {octicon}`beaker;2.5em;sd-mr-1` How-to
:link: how_to/index
:link-type: doc

How-to guides provide step by step recipes for solving essential problems and tasks that arise during your work.
:::

:::{grid-item-card} {octicon}`mortar-board;2.5em;sd-mr-1` Explanation
:link: explanation/index
:link-type: doc

Introduces you to some of the core concepts behind Panel and some of the advanced features that make Panel such a powerful library.
:::

:::{grid-item-card} {octicon}`book;2.5em;sd-mr-1` API Reference
:link: api/index
:link-type: doc

The Panel API Reference Manual provides a comprehensive reference for all methods and parameters on Panel components.
:::

::::

For usage questions or technical assistance, please head over to [Discourse](https://discourse.holoviz.org/) or our [Discord server](https://discord.gg/muhupDZM). If you have any [issues](https://github.com/holoviz/panel/issues), [feature requests](https://github.com/holoviz/panel/issues) or wish to [contribute](https://github.com/holoviz/panel/blob/main/CONTRIBUTING.MD), you can visit our [GitHub site](https://github.com/holoviz/panel).

## Sponsors

The Panel project is grateful for the sponsorship by the organizations and companies below:

::::{grid} 2 2 2 4

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://www.anaconda.com/
:link-type: url
:text-align: center

```{image} https://static.bokeh.org/sponsor/anaconda.png
---
alt: Anaconda Logo
---
```
:::


:::{grid-item-card}
:class-body: sponsor-logo
:link: https://www.blackstone.com/the-firm/
:link-type: url
:text-align: center

```{image} https://static.bokeh.org/sponsor/blackstone.png
---
alt: Blackstone Logo
---
```
:::

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://numfocus.org/
:link-type: url
:text-align: center

```{image} https://numfocus.org/wp-content/uploads/2017/03/numfocusweblogo_orig-1.png
---
alt: NumFOCUS Logo
---
```
:::

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://quansight.com/
:link-type: url
:text-align: center

```{image} https://assets.holoviz.org/logos/Quansight-logo.svg
---
alt: Quansight Logo
---
```
:::

::::


```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2
:caption: FOR USERS

getting_started/index
how_to/index
explanation/index
reference/index
gallery/index
api/index
upgrade
FAQ
about/index
```

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2
:caption: FOR DEVELOPERS

developer_guide/index
```

==> panel-1.4.0b2.tar.gz: panel-1.4.0b2/doc/index.md <==
---
sd_hide_title: true
---

```{image} _static/logo_horizontal_dark_theme.png
:class: only-dark homepage-logo
:width: 250px
```

```{image} _static/logo_horizontal_light_theme.png
:class: only-light homepage-logo
:width: 250px
```

# Overview

<h2 style="margin-top: 0.3em;">The powerful data exploration & web app framework for Python</h2>

::::{grid} 2 4 4 4

:::{grid-item-card} Portfolio Analyzer
:link: https://|gallery-endpoint|.holoviz.dsp.anaconda.com/portfolio_analyzer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/portfolio_analyzer.png
---
alt: Portfolio Analyzer App
---
```
:::

:::{grid-item-card} Portfolio Optimizer
:link: https://|gallery-endpoint|.holoviz.dsp.anaconda.com/portfolio_optimizer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/portfolio_optimizer.png
---
alt: Portfolio Optimizer App
---
```
:::

:::{grid-item-card} MRI Slicer
:link: https://|gallery-endpoint|.holoviz.dsp.anaconda.com/vtk_slicer
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/vtk_slicer.png
---
alt: VTK 3D Slicer App
---
```
:::

:::{grid-item-card} Videostream
:link: https://|gallery-endpoint|.holoviz.dsp.anaconda.com/streaming_videostream
:link-type: url

```{image} https://assets.holoviz.org/panel/gallery/streaming_videostream.png
---
alt: scikit-image Videostream App
---
```
:::

::::

Panel is an [open-source](https://github.com/holoviz/panel/blob/main/LICENSE.txt) Python library that lets you **easily build powerful tools, dashboards and complex applications entirely in Python**. It has a batteries-included philosophy, putting the PyData ecosystem, powerful data tables and much more at your fingertips. High-level reactive APIs and lower-level callback based APIs ensure you can quickly build exploratory applications, but you aren't limited if you build complex, multi-page apps with rich interactivity. Panel is a member of the [HoloViz](https://holoviz.org/) ecosystem, your gateway into a connected ecosystem of data exploration tools.

```{notebook} panel ../examples/homepage.ipynb
:disable_interactivity_warning: True
```

Panel makes it simple to:

- Develop in your favorite **editor or notebook** environment
- Combine the **PyData tools and plotting libraries** that you know and love
- **Iterate quickly** to develop data tools, dashboards and complex apps
- **Collaborate** across skill levels and tool preferences
- Add **advanced bi-directional communication** to your data apps
- Create interactive **big data** applications with **crossfiltering**
- Create **high performing**, **streaming** data applications
- Create data apps that **can run entirely in the browser**
- Create **polished, performant, secure and production-ready web applications**

---

Enjoying Panel? Show your support with a [Github star](https://github.com/holoviz/panel) — it’s a simple click that means the world to us and helps others discover it too! ⭐️

## Learn Panel

::::{grid} 1 2 2 4
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1` Getting Started
:link: getting_started/index
:link-type: doc

The getting started guide will get you set up with Panel and provide a basic overview of the features and strengths of Panel.
:::

:::{grid-item-card} {octicon}`mortar-board;2.5em;sd-mr-1` Tutorials
:link: tutorials/index
:link-type: doc

Through guided steps and activities the tutorials will help you acquire the skills and knowledge to use Panel.
:::

:::{grid-item-card} {octicon}`telescope;2.5em;sd-mr-1` Explanation
:link: explanation/index
:link-type: doc

Introduces you to some of the core concepts behind Panel and some of the advanced features that make Panel such a powerful library.
:::

::::

## Use Panel

::::{grid} 1 2 2 4
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`package;2.5em;sd-mr-1` Component Gallery
:link: reference/index
:link-type: doc

The Component Gallery showcases Panel's components and their essential reference guides, offering users vital usage information.
:::

:::{grid-item-card} {octicon}`beaker;2.5em;sd-mr-1` How-to
:link: how_to/index
:link-type: doc

How-to guides provide step by step recipes for solving essential problems and tasks that arise during your work.
:::

:::{grid-item-card} {octicon}`book;2.5em;sd-mr-1` API Reference
:link: api/index
:link-type: doc

The Panel API Reference Manual furnishes an extensive guide covering Panels methods and parameters.
:::

::::

For usage questions or technical assistance, please head over to [Discourse](https://discourse.holoviz.org/) or our [Discord server](https://discord.gg/muhupDZM). If you have any [issues](https://github.com/holoviz/panel/issues), [feature requests](https://github.com/holoviz/panel/issues) or wish to [contribute](https://github.com/holoviz/panel/blob/main/CONTRIBUTING.MD), you can visit our [GitHub site](https://github.com/holoviz/panel).

## Sponsors

The Panel project is grateful for the sponsorship by the organizations and companies below:

::::{grid} 2 2 2 4

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://www.anaconda.com/
:link-type: url
:text-align: center

```{image} https://static.bokeh.org/sponsor/anaconda.png
---
alt: Anaconda Logo
---
```
:::


:::{grid-item-card}
:class-body: sponsor-logo
:link: https://www.blackstone.com/the-firm/
:link-type: url
:text-align: center

```{image} https://static.bokeh.org/sponsor/blackstone.png
---
alt: Blackstone Logo
---
```
:::

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://numfocus.org/
:link-type: url
:text-align: center

```{image} https://numfocus.org/wp-content/uploads/2017/03/numfocusweblogo_orig-1.png
---
alt: NumFOCUS Logo
---
```
:::

:::{grid-item-card}
:class-body: sponsor-logo
:link: https://quansight.com/
:link-type: url
:text-align: center

```{image} https://assets.holoviz.org/logos/Quansight-logo.svg
---
alt: Quansight Logo
---
```
:::

::::


```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2
:caption: FOR USERS

getting_started/index
tutorials/index
explanation/index
reference/index
how_to/index
gallery/index
api/index
community
upgrade
FAQ
about/index
```

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2
:caption: FOR DEVELOPERS

developer_guide/index
```
